@@ -50,19 +50,43 @@ class ConfigPersistence:
         return loaded_models
 
     def get_import_database_models_func(self, persistence_entry):
-        def _delete_module_if_already_imported(module_name: str):
+        def _is_class_in_sqlalchemy_tables(class_model_name: str):
+            # We need this to filter deletion in case of Model dependencies.
+            # For instance, ClientConfigModel imports ClientModel on class model definition
+            # It throws the following error:
+            #  sqlalchemy.exc.InvalidRequestError: Table 'ClientConfig' is already defined for this MetaData instance.
+            #  Specify 'extend_existing=True' to redefine options and columns on an existing Table object.
+            # As a workaround, we only delete the module if it not exist in SQLAlchemy tables.
+            from petisco.persistence.sqlalchemy.sqlalchemy_persistence import (
+                SqlAlchemyPersistence,
+            )
+
+            is_in_tables = False
+            for source in SqlAlchemyPersistence.get_instance().sources.values():
+                Base = source.get("base")
+                if not Base:
+                    continue
+                is_in_tables = class_model_name.replace("Model", "") in list(
+                    Base.metadata.tables.keys()
+                )
+            return is_in_tables
+
+        def _delete_module_if_already_imported(module_name: str, class_model_name: str):
             # Important. SqlAlchemy needs models to be imported
             # Base = SqlAlchemyPersistence.get_instance().sources["petisco"]["base"]
             # If module is already imported and Base has not tables, Tables won't be imported.
+            # This, usually happens when start the application (e.g end2end tests)
             # e.g len(Base.metadata.tables) == 0
-            # With this function we ensure that model can be imported to help SqlAlchemy loading models
-            if module_name in sys.modules:
+            # With this function we ensure that model can be imported to help SqlAlchemy loading models if is not imported yet
+            if module_name in sys.modules and not _is_class_in_sqlalchemy_tables(
+                class_model_name
+            ):
                 del sys.modules[module_name]
 
         def _import_database_models_func():
             for name, model_string in self.configs[persistence_entry].models.items():
                 module_name, class_model_name = model_string.rsplit(".", 1)
-                _delete_module_if_already_imported(module_name)
+                _delete_module_if_already_imported(module_name, class_model_name)
                 importlib.import_module(module_name, class_model_name)
 
         return _import_database_models_func
