@@ -1,5 +1,6 @@
 import json
 from json.decoder import JSONDecodeError
+from typing import Tuple
 
 from meiga import Error
 
@@ -20,14 +21,14 @@ def get_error_message(error_message_title, response):
 
 class RequestError(Error):
     def __init__(
-            self,
-            error_name: str,
-            error_message: str,
-            status_code: int,
-            url: str,
-            headers: dict = None,
-            content: dict = None,
-            completed_in_ms: float = None,
+        self,
+        error_name: str,
+        error_message: str,
+        status_code: int,
+        url: str,
+        headers: dict = None,
+        content: dict = None,
+        completed_in_ms: float = None,
     ):
         self.error_name = error_name
         self.error_message = error_message
@@ -72,18 +73,19 @@ class MissingSchemaRequestError(RequestError):
             error_name="MissingSchemaRequestError",
             error_message=json.dumps({"error": "Missing schema in request"}),
             status_code=422,
-            url=url
+            url=url,
         )
 
 
 class TimeoutRequestError(RequestError):
-    def __init__(self, url: str):
+    def __init__(self, url: str, timeout: Tuple[int, int]):
         super().__init__(
             error_name="TimeoutRequestError",
             error_message=json.dumps({"error": "Timeout error"}),
             status_code=408,
-            url=url
+            url=url,
         )
+        self.timeout = timeout
 
 
 class ConnectionRequestError(RequestError):
@@ -92,7 +94,7 @@ class ConnectionRequestError(RequestError):
             error_name="ConnectionRequestError",
             error_message=json.dumps({"error": "Connection error"}),
             status_code=503,
-            url=url
+            url=url,
         )
 
 
@@ -146,5 +148,5 @@ class UnknownRequestError(RequestError):
             error_name="UnknownRequestError",
             error_message=str(exc),
             status_code=500,
-            url=url
+            url=url,
         )
